@@ -1,16 +1,19 @@
 
 class filter_data:
-    def __int__(self):
+    def __int__(self,df,columns,val):
         self.self=self
+        self.df=df
+        self.columns=columns
+        self.val=val
     ''' In multiple filter function you can filter upto ten data 10 
     only you have to pass yor value as list(respect to multiple filter)'''
-    def pysprk_filter(self,df,val):
+    def pysprk_filter(self,df,columns,val):
         '''
         df="Data Frame"
         Column="target column"
         val -> "string/List"
         '''
-        column=input('Enter your target ciolumn name :')
+        #column=input('Enter your target ciolumn name :')
         typ=input("kindly enter \n which filter do you want to perorm\n 0 -> 'Equal'\n 1 -> 'not-Equal' \n 2 -> 'isnull' \n kindly pass your value as 1 or 2 or 3 \n")
         if typ=="0":
             if type(val)==list and len(val)<=10:
